from .ar import Arabic
from .bg import Bulgarian
from .bn import Bengali
from .ca import Catalan
from .da import Danish
from .de import Deutsch
from .el import Greek
from .en import English
from .fi import Finnish
from .fr import French
from .gu import Gujarati
from .hi import Hindi
from .hy import Armenian
from .it import Italian
from .kk import Kazakh
from .kn import Kannada
from .ml import Malayalam
from .mr import Marathi
from .my import Burmese
from .nl import Dutch
from .or_ import Odia
from .pa import Punjabi
from .pl import Polish
from .pt import Portuguese
from .ru import Russian
from .sk import Slovak
from .ta import Tamil
from .te import Telugu

__all__ = [
    "Arabic",
    "Armenian",
    "Bengali",
    "Bulgarian",
    "Burmese",
    "Catalan",
    "Danish",
    "Deutsch",
    "Dutch",
    "English",
    "Finnish",
    "French",
    "Gujarati",
    "Greek",
    "Hindi",
    "Italian",
    "Kannada",
    "Kazakh",
    "Malayalam",
    "Marathi",
    "Odia",
    "Punjabi",
    "Polish",
    "Portuguese",
    "Russian",
    "Slovak",
    "Spanish",
    "Tamil",
    "Telugu",
]
