from sentencex.base import Language


class English(Language):
    language = "en"

    abbreviations = {
        "A",
        "adj",
        "adm",
        "adv",
        "al",
        "ala",
        "alta",
        "apr",
        "arc",
        "ariz",
        "ark",
        "art",
        "assn",
        "asst",
        "attys",
        "aug",
        "ave",
        "B",
        "bart",
        "bld",
        "bldg",
        "blvd",
        "brig",
        "bros",
        "btw",
        "C",
        "cal",
        "calif",
        "capt",
        "cl",
        "cmdr",
        "co",
        "col",
        "colo",
        "comdr",
        "con",
        "conn",
        "corp",
        "cpl",
        "cres",
        "ct",
        "d.phil",
        "D",
        "dak",
        "dec",
        "del",
        "dept",
        "det",
        "dist",
        "dr.phil",
        "dr.philos",
        "dr",
        "drs",
        "e.g",
        "E",
        "ens",
        "esp",
        "esq",
        "etc",
        "exp",
        "expy",
        "ext",
        "F",
        "feb",
        "fed",
        "fig",
        "fla",
        "ft",
        "fwy",
        "fy",
        "G",
        "ga",
        "gen",
        "gov",
        "H",
        "hon",
        "hosp",
        "hr",
        "hway",
        "hwy",
        "i.e",
        "I",
        "ia",
        "id",
        "ida",
        "ill",
        "inc",
        "ind",
        "ing",
        "insp",
        "J",
        "jan",
        "jr",
        "jul",
        "jun",
        "K",
        "kan",
        "kans",
        "ken",
        "ky",
        "L",
        "la",
        "lt",
        "ltd",
        "M",
        "maj",
        "man",
        "mar",
        "mass",
        "may",
        "md",
        "me",
        "med",
        "messrs",
        "mex",
        "mfg",
        "mich",
        "min",
        "minn",
        "miss",
        "mlle",
        "mm",
        "mme",
        "mo",
        "mont",
        "mr",
        "mrs",
        "ms",
        "msgr",
        "mssrs",
        "mt",
        "mtn",
        "Nº",
        "N°",
        "No̱",
        "No",
        "N",
        "neb",
        "nebr",
        "nev",
        "no",
        "nos",
        "nov",
        "nr",
        "O",
        "oct",
        "ok",
        "okla",
        "ont",
        "op",
        "ord",
        "ore",
        "p",
        "P",
        "pa",
        "pd",
        "pde",
        "penn",
        "penna",
        "pfc",
        "ph.d",
        "ph",
        "pl",
        "plz",
        "pp",
        "prof",
        "pvt",
        "Q",
        "que",
        "R",
        "rd",
        "ref",
        "rep",
        "reps",
        "res",
        "rev",
        "rs",
        "rt",
        "S",
        "sask",
        "sec",
        "sen",
        "sens",
        "sep",
        "sept",
        "sfc",
        "sgt",
        "sr",
        "st",
        "supt",
        "surg",
        "T",
        "tce",
        "tenn",
        "tex",
        "u.s",
        "U",
        "univ",
        "usafa",
        "ut",
        "v",
        "V",
        "va",
        "ver",
        "viz",
        "vs",
        "vt",
        "W",
        "wash",
        "wis",
        "wisc",
        "wy",
        "wyo",
        "X",
        "Y",
        "yuk",
        "Z",
    }
