from sentencex.base import Language


class Arabic(Language):
    language = "ar"

    abbreviations = {
        "إلخ",
        "ا. د",
        "ا.د",
        "ا.ش.ا",
        "ا",
        "ت.ب",
        "ج.ب",
        "ج.م.ع",
        "جم",
        "س.ت",
        "سم",
        "ص.ب.",
        "ص.ب",
        "كج.",
        "كلم.",
        "م.ب",
        "م",
        "ه",
    }
